@@ -95,10 +95,20 @@ void ConnectionWirelessEditPage::initApSecretType(AccessPoint::Ptr nmAp)
             rsnFlags.testFlag(AccessPoint::WpaFlag::KeyMgmtPsk))
         keyMgmt = WirelessSecuritySetting::KeyMgmt::WpaPsk;
 
+#ifdef USE_DEEPIN_NMQT
+    NetworkManager::AccessPoint::WpaFlag accessPointWpaFlagState = NetworkManager::AccessPoint::WpaFlag::keyMgmtSae;
+#else
+    NetworkManager::AccessPoint::WpaFlag accessPointWpaFlagState = NetworkManager::AccessPoint::WpaFlag::KeyMgmtSAE;
+#endif
+
     // 判断是否是wpa3加密的，因为wpa3加密方式，实际上是wpa2的扩展，所以其中会包含KeyMgmtPsk枚举值
-    if (wpaFlags.testFlag(NetworkManager::AccessPoint::WpaFlag::keyMgmtSae) ||
-        rsnFlags.testFlag(NetworkManager::AccessPoint::WpaFlag::keyMgmtSae)) {
+    if (wpaFlags.testFlag(accessPointWpaFlagState) ||
+        rsnFlags.testFlag(accessPointWpaFlagState)) {
+#ifdef USE_DEEPIN_NMQT
         keyMgmt = NetworkManager::WirelessSecuritySetting::KeyMgmt::WpaSae;
+#else
+        keyMgmt = NetworkManager::WirelessSecuritySetting::KeyMgmt::SAE;
+#endif
     }
 
     if (wpaFlags.testFlag(AccessPoint::WpaFlag::KeyMgmt8021x) ||
