@@ -133,16 +133,15 @@ void DCCNetworkModule::active()
     initListConfig();
     m_indexWidget->showDefaultWidget();
 
-    if (supportAirplaneMode()) {
+    if (getAirplaneDconfig()) {
         m_networkInter = new NetworkInter("com.deepin.daemon.Network", "/com/deepin/daemon/Network", QDBusConnection::sessionBus(), this);
         connect(m_networkInter, &NetworkInter::WirelessAccessPointsChanged, this, &DCCNetworkModule::onWirelessAccessPointsOrAdapterChange);
 
         m_bluetoothInter = new BluetoothInter("com.deepin.daemon.Bluetooth", "/com/deepin/daemon/Bluetooth", QDBusConnection::sessionBus(), this);
         connect(m_bluetoothInter, &BluetoothInter::AdapterAdded, this, &DCCNetworkModule::onWirelessAccessPointsOrAdapterChange);
         connect(m_bluetoothInter, &BluetoothInter::AdapterRemoved, this, &DCCNetworkModule::onWirelessAccessPointsOrAdapterChange);
-    } else {
-        onWirelessAccessPointsOrAdapterChange();
     }
+    onWirelessAccessPointsOrAdapterChange();
 }
 
 QStringList DCCNetworkModule::availPage() const
@@ -353,6 +352,15 @@ bool DCCNetworkModule::supportAirplaneMode() const
     return false;
 }
 
+bool DCCNetworkModule::getAirplaneDconfig() const
+{
+    bool airplane = false;
+    if (m_dconfig && m_dconfig->isValid()) {
+        airplane = m_dconfig->value("networkAirplaneMode", false).toBool();
+    }
+    return airplane;
+}
+
 void DCCNetworkModule::initSearchData()
 {
     if (!m_frameProxy)
@@ -710,8 +718,8 @@ void DCCNetworkModule::showDeviceDetailPage(NetworkDeviceBase *dev, const QStrin
             m_frameProxy->pushWidget(this, w, dccV20::FrameProxyInterface::PushType::CoverTop);
             wirelessPage->setVisible(true);
         });
-        connect(m_airplaneMode, &DBusAirplaneMode::EnabledChanged, wirelessPage, &WirelessPage::onAirplaneModeChanged);
-        wirelessPage->onAirplaneModeChanged(m_airplaneMode->enabled());
+        connect(m_airplaneMode, &DBusAirplaneMode::WifiEnabledChanged, wirelessPage, &WirelessPage::onAirplaneModeChanged);
+        wirelessPage->onAirplaneModeChanged(m_airplaneMode->wifiEnabled());
 
         wirelessPage->jumpByUuid(searchPath);
     } else if (dev->deviceType() == DeviceType::Wired) {
@@ -753,11 +761,11 @@ void DCCNetworkModule::showProxyPage()
 void DCCNetworkModule::showHotspotPage(const QString &searchPath)
 {
     HotspotPage *hotspot = new HotspotPage();
-    hotspot->onAirplaneModeChanged(m_airplaneMode->enabled());
+    hotspot->onAirplaneModeChanged(m_airplaneMode->wifiEnabled());
     connect(hotspot, &HotspotPage::requestNextPage, this, [ = ](ContentWidget * const w) {
         m_frameProxy->pushWidget(this, w, dccV20::FrameProxyInterface::PushType::CoverTop);
     });
-    connect(m_airplaneMode, &DBusAirplaneMode::EnabledChanged, hotspot, &HotspotPage::onAirplaneModeChanged);
+    connect(m_airplaneMode, &DBusAirplaneMode::WifiEnabledChanged, hotspot, &HotspotPage::onAirplaneModeChanged);
     m_frameProxy->pushWidget(this, hotspot);
     hotspot->jumpPath(searchPath);
 }
