@@ -53,7 +53,7 @@ Secret8021xSection::Secret8021xSection(Security8021xSetting::Ptr sSetting, QFram
     m_currentEapMethod = eapMethods.isEmpty() ? Security8021xSetting::EapMethodTls : eapMethods.first();
 
     // init password type
-    Setting::SecretFlags passwordFlags = m_secretSetting->passwordFlags();
+    Setting::SecretFlags passwordFlags = m_currentEapMethod == Security8021xSetting::EapMethodTls ? m_secretSetting->privateKeyPasswordFlags() : m_secretSetting->passwordFlags();
     for (auto it = PasswordFlagsStrMap.cbegin(); it != PasswordFlagsStrMap.cend(); ++it) {
         if (passwordFlags.testFlag(it->second)) {
             m_currentPasswordType = it->second;
