@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Sauvegarder</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Déconnecter</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Êtes-vous sûr de vouloir supprimer cette configuration ?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mode avion</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Adaptateur réseau filaire</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mode avion</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -471,7 +496,7 @@
     <name>IPV4InputSection</name>
     <message>
         <source>Duplicate IP address</source>
-        <translation type="unfinished"/>
+        <translation>Adresse IP en double</translation>
     </message>
     <message>
         <source>Invalid IP address</source>
@@ -483,7 +508,7 @@
     </message>
     <message>
         <source>Only one gateway is allowed</source>
-        <translation type="unfinished"/>
+        <translation>Une seule passerelle est autorisée</translation>
     </message>
     <message>
         <source>Invalid gateway</source>
@@ -502,7 +527,7 @@
     <name>IPV6InputSection</name>
     <message>
         <source>Duplicate IP address</source>
-        <translation type="unfinished"/>
+        <translation>Adresse IP en double</translation>
     </message>
     <message>
         <source>Invalid IP address</source>
@@ -510,7 +535,7 @@
     </message>
     <message>
         <source>Only one gateway is allowed</source>
-        <translation type="unfinished"/>
+        <translation>Une seule passerelle est autorisée</translation>
     </message>
     <message>
         <source>Invalid gateway</source>
@@ -589,7 +614,7 @@
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"/>
+        <translation>Conflit IP</translation>
     </message>
 </context>
 <context>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Proxy d&apos;application</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Mode avion</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Détails du réseau</translation>
@@ -654,7 +684,7 @@
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"/>
+        <translation>Conflit IP</translation>
     </message>
     <message>
         <source>Disabled</source>
@@ -986,7 +1016,7 @@
     </message>
     <message>
         <source>WPA3 Personal</source>
-        <translation type="unfinished"/>
+        <translation>WPA3 Personnel</translation>
     </message>
     <message>
         <source>Security</source>
@@ -1036,7 +1066,7 @@
     </message>
     <message>
         <source>WPA3 Personal</source>
-        <translation type="unfinished"/>
+        <translation>WPA3 Personnel</translation>
     </message>
     <message>
         <source>Shared key</source>
@@ -1493,7 +1523,7 @@
     </message>
     <message>
         <source>OK</source>
-        <translation>D&apos;accord</translation>
+        <translation>OK</translation>
     </message>
 </context>
 <context>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Type de sécurité</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Bande</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Bande</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interface</translation>
@@ -2007,7 +2037,7 @@
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"/>
+        <translation>Conflit IP</translation>
     </message>
     <message>
         <source>Failed</source>
@@ -2015,7 +2045,7 @@
     </message>
     <message>
         <source>Obtaining address</source>
-        <translation type="unfinished"/>
+        <translation>Obtenir l&apos;adresse</translation>
     </message>
 </context>
 <context>
