@@ -35,7 +35,7 @@
     </message>
     <message>
         <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
-        <translation>Zaznacz „Użyj proxy” w menu kontekstowym aplikacji w Launcherze po skonfigurowaniu</translation>
+        <translation>Zaznacz „Użyj proxy” w menu kontekstowym aplikacji w programie wywołującym po skonfigurowaniu</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Zapisz</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Rozłącz</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Czy na pewno chcesz usunąć tę konfigurację?</translation>
@@ -103,7 +111,7 @@
     <name>ConnectionVpnEditPage</name>
     <message>
         <source>New VPN</source>
-        <translation>Nowe VPN</translation>
+        <translation>Nowy VPN</translation>
     </message>
     <message>
         <source>VPN Type</source>
@@ -175,7 +183,7 @@
     </message>
     <message>
         <source>Personal Hotspot</source>
-        <translation>Osobisty hotspot</translation>
+        <translation>Osobisty Hotspot</translation>
     </message>
     <message>
         <source>Network Details</source>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Tryb samolotowy</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Przewodowa karta sieciowa</translation>
@@ -235,7 +249,7 @@
     </message>
     <message>
         <source>VPN Status</source>
-        <translation>Stan VPN</translation>
+        <translation>Status VPN</translation>
         <extra-child_page>VPN</extra-child_page>
         <extra-contents_path>/network/VPN</extra-contents_path>
     </message>
@@ -293,7 +307,7 @@
     </message>
     <message>
         <source>Create Hotspot</source>
-        <translation>Utwórz hotspot</translation>
+        <translation>Utwórz Hotspot</translation>
         <extra-child_page>Personal Hotspot</extra-child_page>
         <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
     </message>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Tryb samolotowy</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>Włączenie trybu samolotowego wyłączy sieć bezprzewodową, osobisty Hotspot i Bluetooth</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -449,7 +474,7 @@
     <name>HotspotPage</name>
     <message>
         <source>Create Hotspot</source>
-        <translation>Utwórz hotspot</translation>
+        <translation>Utwórz Hotspot</translation>
     </message>
 </context>
 <context>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Proxy aplikacji</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Tryb samolotowy</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Szczegóły sieci</translation>
@@ -670,11 +700,11 @@
     </message>
     <message>
         <source>Configure by Network Manager</source>
-        <translation>Skonfiguruj przy użyciu Menedżera Sieci</translation>
+        <translation>Skonfiguruj przy użyciu menedżera sieci</translation>
     </message>
     <message>
         <source>Personal Hotspot</source>
-        <translation>Osobisty hotspot</translation>
+        <translation>Osobisty Hotspot</translation>
     </message>
 </context>
 <context>
@@ -1146,7 +1176,7 @@
     </message>
     <message>
         <source>Weak</source>
-        <translation>Słaby</translation>
+        <translation>Słabe</translation>
     </message>
     <message>
         <source>None</source>
@@ -1473,7 +1503,7 @@
     <name>VpnPage</name>
     <message>
         <source>VPN Status</source>
-        <translation>Stan VPN</translation>
+        <translation>Status VPN</translation>
     </message>
     <message>
         <source>Create VPN</source>
@@ -1864,7 +1894,7 @@
     </message>
     <message>
         <source>Disable hotspot first if you want to connect to a wireless network</source>
-        <translation>Jeśli chcesz połączyć się z siecią bezprzewodową, najpierw wyłącz hotspot</translation>
+        <translation>Jeśli chcesz połączyć się z siecią bezprzewodową, najpierw wyłącz Hotspot</translation>
     </message>
     <message>
         <source>Connect to hidden network</source>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Typ zabezpieczenia</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Pasmo</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Kanał</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Pasmo</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interfejs</translation>
