@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>Сохранить</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Отключить</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>Вы уверены, что хотите удалить эту конфигурацию?</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Авиарежим</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>Проводной сетевой адаптер</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Авиарежим</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -589,7 +614,7 @@
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"/>
+        <translation>Конфликт IP-адресов</translation>
     </message>
 </context>
 <context>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>Прокси приложения</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>Авиарежим</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>Детали сети</translation>
@@ -654,7 +684,7 @@
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"/>
+        <translation>Конфликт IP-адресов</translation>
     </message>
     <message>
         <source>Disabled</source>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>Тип безопасности</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Диапазон</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Канал</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Диапазон</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Интерфейс</translation>
@@ -2007,7 +2037,7 @@
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"/>
+        <translation>Конфликт IP-адресов</translation>
     </message>
     <message>
         <source>Failed</source>
@@ -2015,7 +2045,7 @@
     </message>
     <message>
         <source>Obtaining address</source>
-        <translation type="unfinished"/>
+        <translation>Получение адреса</translation>
     </message>
 </context>
 <context>
