@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>保 存</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation>正在连接</translation>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>断开连接</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>您确定要删除当前配置吗？</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飞行模式</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>有线网卡</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飞行模式</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>打开飞行模式将关闭无线网络、个人热点和蓝牙功能</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>应用代理</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飞行模式</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>网络详情</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>安全类型</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>频段</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>网络通道</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>频段</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>接口</translation>
