@@ -78,6 +78,14 @@
         <comment>button</comment>
         <translation>保 存</translation>
     </message>
+    <message>
+        <source>Connecting</source>
+        <translation>正在連接</translation>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>斷開連接</translation>
+    </message>
     <message>
         <source>Are you sure you want to delete this configuration?</source>
         <translation>您確定要刪除當前配置嗎？</translation>
@@ -197,6 +205,12 @@
         <source>VPN</source>
         <translation>VPN</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飛行模式</translation>
+        <extra-child_page>Airplane Mode</extra-child_page>
+        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
+    </message>
     <message>
         <source>Wired Network Adapter</source>
         <translation>有線網卡</translation>
@@ -358,6 +372,17 @@
         <extra-contents_path>/network/Network Details</extra-contents_path>
     </message>
 </context>
+<context>
+    <name>dccV20::network::AirplaneModepage</name>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飛行模式</translation>
+    </message>
+    <message>
+        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
+        <translation>打開飛行模式將關閉無線網絡、個人熱點和藍牙功能</translation>
+    </message>
+</context>
 <context>
     <name>DNSSection</name>
     <message>
@@ -644,6 +669,11 @@
         <source>Application Proxy</source>
         <translation>應用代理</translation>
     </message>
+    <message>
+        <source>Airplane Mode</source>
+        <translation>飛行模式</translation>
+        <extra-contents_path>/network/Airplane</extra-contents_path>
+    </message>
     <message>
         <source>Network Details</source>
         <translation>網絡詳情</translation>
@@ -1922,14 +1952,14 @@
         <source>Security Type</source>
         <translation>安全類型</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>頻段</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>聲道</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>頻段</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>接口</translation>
