@@ -33,6 +33,7 @@
 #include <QAccessibleEvent>
 #include <QString>
 #include <QPainterPath>
+#include <DDBusSender>
 
 #include <iostream>
 
@@ -64,6 +65,7 @@ DockPopupWindow::DockPopupWindow(RunReason runReaseon, QWidget *parent)
         setWindowFlags(windowFlags() | Qt::Dialog | Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint);
         setAttribute(Qt::WA_NativeWindow);
         windowHandle()->setProperty("_d_dwayland_window-type", "override");
+        QDBusConnection::sessionBus().connect("com.deepin.dde.lockFront", "/com/deepin/dde/lockFront", "com.deepin.dde.lockFront", "Visible", this, SLOT(lockFrontVisible(bool)));
     } else {
         if (runReaseon == Lock || runReaseon == Greeter)
             setWindowFlags(Qt::Popup | Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);
@@ -82,6 +84,13 @@ DockPopupWindow::DockPopupWindow(RunReason runReaseon, QWidget *parent)
     connect(m_regionInter, &DRegionMonitor::buttonPress, this, &DockPopupWindow::onGlobMouseRelease);
 }
 
+void DockPopupWindow::lockFrontVisible(bool visible)
+{
+    if (visible) {
+        closeDialog();
+    }
+}
+
 DockPopupWindow::~DockPopupWindow()
 {
     if (m_bgImage) {
@@ -141,6 +150,10 @@ void DockPopupWindow::show(const int x, const int y)
 
 void DockPopupWindow::showEvent(QShowEvent *e)
 {
+    // 显示的时候主动去grab键盘（如果不主动抓取，在社区版上弹窗大概率没有抓取到键盘，可能跟qt的版本有关）
+    if (window() && window()->windowHandle()) {
+        window()->windowHandle()->setKeyboardGrabEnabled(true);
+    }
     DArrowRectangle::showEvent(e);
     QTimer::singleShot(1, this, &DockPopupWindow::ensureRaised);
 }
