@@ -58,7 +58,6 @@ void IPConfilctChecker::clearUnExistDevice()
 
 void IPConfilctChecker::onIPConfilct(const QString &ip, const QString &macAddress)
 {
-    PRINT_INFO_MESSAGE(QString("received:ip %1, macaddress %2").arg(ip).arg(macAddress));
     // 此处通过调用后台获取IP地址，如果直接使用当前网络库中设备的IP地址，就有如下问题
     // 如果是在控制中心修改手动IP的话，从当前库中获取到的IP地址就不是最新的地址，因此此处需要从后台获取实时IP
     QDBusPendingCallWatcher *w = new QDBusPendingCallWatcher(m_networkInter->GetActiveConnectionInfo(), this);
@@ -80,7 +79,6 @@ void IPConfilctChecker::onSenderIPInfo(const QStringList &ips)
 
 void IPConfilctChecker::handlerIpConflict(const QString &ip, const QString &macAddress, const QString &activeConnectionInfo)
 {
-    PRINT_INFO_MESSAGE(QString("ip:%1, macAddress: %2").arg(ip).arg(macAddress));
     QMap<QString, NetworkDeviceBase *> deviceIps = parseDeviceIp(activeConnectionInfo);
     NetworkDeviceBase *conflictDevice = Q_NULLPTR;
     if (deviceIps.contains(ip))
@@ -113,7 +111,6 @@ void IPConfilctChecker::handlerIpConflict(const QString &ip, const QString &macA
 
     // 如果不是本机IP，不做任何处理
     if (!conflictDevice) {
-        PRINT_INFO_MESSAGE("can't find conflict Device");
         return;
     }
 
@@ -259,7 +256,6 @@ void DeviceIPChecker::setDeviceInfo(const QStringList &ipv4, const QString &macA
 
 void DeviceIPChecker::handlerIpConflict()
 {
-    PRINT_INFO_MESSAGE(QString("device: %1 ip: %2 mac address:%3").arg(m_device->deviceName()).arg(m_ipV4.join(",")).arg(m_macAddress));
     if (m_macAddress.isEmpty()) {
         m_conflictCount = 0;
         // 如果MAC地址为空，则表示IP冲突已经解决，则让每个网卡恢复之前的状态
@@ -277,15 +273,12 @@ void DeviceIPChecker::handlerIpConflict()
         m_clearCount++;
     } else {
         m_clearCount = 0;
-        PRINT_INFO_MESSAGE(QString("find confilct device:%1, confilctCount:%2, conflictIP: %3").arg(m_device->deviceName()).arg(m_conflictCount).arg(m_ipV4.join(",")));
 
         // 如果少于两次，则继续确认
         if (m_conflictCount < 1 && !m_ipConflicted) {
-            PRINT_INFO_MESSAGE(QString("start confirm %1 times").arg(m_conflictCount));
             emit ipConflictCheck(m_ipV4);
         } else {
             // 如果大于3次，则认为当前IP冲突了
-            PRINT_INFO_MESSAGE(QString("ip Conflicted: %1, device: %2").arg(m_ipV4.join(",")).arg(m_device->deviceName()));
             // 拿到最后一次设备冲突的状态
             bool lastConflictStatus = m_ipConflicted;
             m_ipConflicted = true;
