@@ -28,6 +28,7 @@
 
 namespace NetworkManager {
 class WirelessNetwork;
+class AccessPoint;
 }
 
 using namespace NetworkManager;
@@ -88,7 +89,7 @@ private:
     void syncWlanAndConnections(QList<WirelessConnection *> &allConnections);
 
     AccessPoints *findAccessPoints(const QString &ssid);
-    QJsonObject createWlanJson(QSharedPointer<NetworkManager::WirelessNetwork> network);
+    QJsonObject createWlanJson(QSharedPointer<NetworkManager::AccessPoint> ap);
     QJsonObject createConnectionJson(QSharedPointer<NetworkManager::Connection> networkConnection);
     WirelessConnection *findConnectionByAccessPoint(const AccessPoints *accessPoint, QList<WirelessConnection *> &allConnections);
 
